IndexError

Enum IndexError 

pub enum IndexError {
    OutOfBounds,
    Invalid,
}
The error returned when failing to construct an arbitrary index.

Variants



OutOfBounds

The provided raw index was out of bounds of the container.



Invalid

The provided raw index was in bounds but not on an item border.